@@ -15,9 +15,9 @@ class _EventFramework:
         self._start_flag = False
         self._log_handler = None
 
-    def _newworker(self, timedt=None):
+    def _newworker(self, name=None, timedt=None):
         self._worker_id += 1
-        worker = Worker("worker" + str(self._worker_id - 1) + " of " + self.name, mindt= timedt if timedt else self.timedt)
+        worker = Worker("worker" + str(self._worker_id - 1) + " of " + self.name if name is None else name, mindt= timedt if timedt else self.timedt)
         if self._start_flag:
             worker.start()
         return worker
@@ -104,6 +104,13 @@ class EventFramework(_EventFramework):
         self.ealloter.efr = self
         self._initlogger()
 
+    @property
+    def stations(self):
+        """
+        获取所有已经注册过的station
+        """
+        return self.ealloter.stations
+
     def start(self):
         """
         启动事件框架
@@ -232,15 +239,17 @@ class EventFramework(_EventFramework):
             return worker.addTask(station._task)
 
 
-    def addWorker(self, timedt:int=None) -> Worker:
+    def addWorker(self, name:str=None, timedt:int=None) -> Worker:
         """
         添加一个工人到事件框架
         add a worker to eventframework.
+        :param name: str Worker's name
+                _: None  # mean use the default name
         :param timedt: int Worker's timedt. Mean how frequency the Worker work
                 _: None  # mean use the default timedt defined in EventFramework.__init__
         :return: Worker
         """
-        worker = self._newworker(timedt)
+        worker = self._newworker(name, timedt)
         self.workers += [worker]
         return worker
 
